define({ root:

//begin v1.x content
{
	"field-thu-narrow-relative+0": "this Thursday",
	"field-thu-narrow-relative+1": "next Thursday",
	"dayPeriods-format-wide@localeAlias933": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-sun-narrow-relative+0": "this Sunday",
	"field-sun-narrow-relative+1": "next Sunday",
	"months-format-wide": [
		"Chaitra",
		"Vaisakha",
		"Jyaistha",
		"Asadha",
		"Sravana",
		"Bhadra",
		"Asvina",
		"Kartika",
		"Agrahayana",
		"Pausa",
		"Magha",
		"Phalguna"
	],
	"dayPeriods-standAlone-abbr-pm": "PM",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-fri-narrow-relative+0": "this Friday",
	"eraNarrow": [
		"Saka"
	],
	"field-fri-narrow-relative+1": "next Friday",
	"field-dayOfYear-short@localeAlias965": {
		"bundle": "",
		"target": "field-dayOfYear"
	},
	"field-quarter-narrow@localeAlias951": {
		"bundle": "",
		"target": "field-quarter-short"
	},
	"field-quarter-narrow@localeAlias952": {
		"bundle": "",
		"target": "field-quarter"
	},
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"days-standAlone-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"dateFormatItem-Ehm": "E h:mm a",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-wed-narrow-relative+-1": "last Wednesday",
	"field-minute-narrow-relative+0": "this minute",
	"days-format-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"days-standAlone-abbr@localeAlias919": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"field-month-short-relative+0": "this month",
	"field-month-short-relative+1": "next month",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"field-weekdayOfMonth-narrow@localeAlias972": {
		"bundle": "",
		"target": "field-weekdayOfMonth-short"
	},
	"field-wed-narrow@localeAlias984": {
		"bundle": "",
		"target": "field-wed-short"
	},
	"field-weekdayOfMonth-narrow@localeAlias973": {
		"bundle": "",
		"target": "field-weekdayOfMonth"
	},
	"field-wed-narrow@localeAlias985": {
		"bundle": "",
		"target": "field-wed"
	},
	"field-thu-relative+0": "this Thursday",
	"dayPeriods-format-wide-am": "AM",
	"field-thu-relative+1": "next Thursday",
	"field-thu-short@localeAlias986": {
		"bundle": "",
		"target": "field-thu"
	},
	"field-fri-relative+0": "this Friday",
	"field-fri-relative+1": "next Friday",
	"days-standAlone-abbr@localeAlias920": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-quarter-relative+0": "this quarter",
	"field-thu-narrow-relative+-1": "last Thursday",
	"field-quarter-relative+1": "next quarter",
	"field-weekdayOfMonth-short@localeAlias971": {
		"bundle": "",
		"target": "field-weekdayOfMonth"
	},
	"field-sun-short-relative+0": "this Sunday",
	"timeFormat-short": "HH:mm",
	"field-sun-short-relative+1": "next Sunday",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-Md": "MM-dd",
	"field-tue-short@localeAlias980": {
		"bundle": "",
		"target": "field-tue"
	},
	"field-week-narrow": "Week",
	"quarters@localeAlias925": {
		"bundle": "gregorian",
		"target": "quarters"
	},
	"field-hour-relative+0": "this hour",
	"field-day-relative+-1": "yesterday",
	"field-mon-narrow-relative+-1": "last Monday",
	"field-day-narrow@localeAlias963": {
		"bundle": "",
		"target": "field-day-short"
	},
	"field-day-narrow@localeAlias964": {
		"bundle": "",
		"target": "field-day"
	},
	"field-minute-narrow": "Minute",
	"dateFormatItem-yyyyMMM": "G y MMM",
	"field-thu-short-relative+0": "this Thursday",
	"field-mon-relative+0": "this Monday",
	"field-thu-short-relative+1": "next Thursday",
	"field-mon-relative+1": "next Monday",
	"dateTimeFormats-appendItem-Era": "{1} {0}",
	"field-day-narrow-relative+0": "today",
	"field-era-short": "Era",
	"field-day-narrow-relative+1": "tomorrow",
	"field-sat-narrow-relative+0": "this Saturday",
	"timeFormat-long": "HH:mm:ss z",
	"field-sat-narrow-relative+1": "next Saturday",
	"field-week-narrow-relative+0": "this week",
	"field-week-narrow-relative+1": "next week",
	"dayPeriods-standAlone-narrow@localeAlias935": {
		"bundle": "gregorian",
		"target": "dayPeriods-standAlone-abbr"
	},
	"dayPeriods-standAlone-narrow@localeAlias936": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-hour-short-relative+0": "this hour",
	"field-wed-narrow-relative+0": "this Wednesday",
	"field-wed-narrow-relative+1": "next Wednesday",
	"field-month": "Month",
	"months-standAlone-wide": [
		"Chaitra",
		"Vaisakha",
		"Jyaistha",
		"Asadha",
		"Sravana",
		"Bhadra",
		"Asvina",
		"Kartika",
		"Agrahayana",
		"Pausa",
		"Magha",
		"Phalguna"
	],
	"dateTimeFormats-appendItem-Second": "{0} ({2}: {1})",
	"field-weekday-narrow": "Day of the Week",
	"eraNames@localeAlias939": {
		"bundle": "indian",
		"target": "eraAbbr"
	},
	"field-sat-narrow@localeAlias993": {
		"bundle": "",
		"target": "field-sat-short"
	},
	"days-format-short@localeAlias917": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"field-sat-narrow@localeAlias994": {
		"bundle": "",
		"target": "field-sat"
	},
	"field-year-relative+0": "this year",
	"days-format-short@localeAlias918": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-year-relative+1": "next year",
	"field-minute-short@localeAlias1001": {
		"bundle": "",
		"target": "field-minute"
	},
	"field-tue-relative+0": "this Tuesday",
	"field-tue-relative+1": "next Tuesday",
	"field-minute-short-relative+0": "this minute",
	"dateFormatItem-hm": "h:mm a",
	"field-year-narrow": "Year",
	"field-year-short@localeAlias947": {
		"bundle": "",
		"target": "field-year"
	},
	"dateTimeFormats-appendItem-Day": "{0} ({2}: {1})",
	"field-second-narrow@localeAlias1005": {
		"bundle": "",
		"target": "field-second-short"
	},
	"field-tue-short-relative+0": "this Tuesday",
	"field-second-narrow@localeAlias1006": {
		"bundle": "",
		"target": "field-second"
	},
	"field-tue-short-relative+1": "next Tuesday",
	"field-mon-short@localeAlias977": {
		"bundle": "",
		"target": "field-mon"
	},
	"dateTimeFormats-appendItem-Year": "{1} {0}",
	"dateTimeFormats-appendItem-Day-Of-Week": "{0} {1}",
	"dayPeriods-format-narrow@localeAlias932": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-tue-narrow-relative+0": "this Tuesday",
	"field-tue-narrow-relative+1": "next Tuesday",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-E": "ccc",
	"field-era-short@localeAlias944": {
		"bundle": "",
		"target": "field-era"
	},
	"dateFormatItem-EBhm": "E h:mm B",
	"dateFormatItem-H": "HH",
	"field-wed-relative+0": "this Wednesday",
	"field-wed-relative+1": "next Wednesday",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "this Wednesday",
	"field-wed-short-relative+1": "next Wednesday",
	"field-fri-short-relative+0": "this Friday",
	"field-weekOfMonth-short": "Week Of Month",
	"field-fri-short-relative+1": "next Friday",
	"field-quarter-short-relative+-1": "last quarter",
	"field-year-short-relative+-1": "last year",
	"dateFormatItem-Bhm": "h:mm B",
	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
	"dateTimeFormat-medium": "{1} {0}",
	"field-quarter-narrow-relative+-1": "last quarter",
	"dateFormatItem-d": "d",
	"dayPeriods-standAlone-abbr@localeAlias934": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"dayPeriods-format-abbr-pm": "PM",
	"dateFormatItem-h": "h a",
	"months-standAlone-abbr@localeAlias911": {
		"bundle": "indian",
		"target": "months-format-abbr"
	},
	"quarters-standAlone-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"timeFormat@localeAlias942": {
		"bundle": "gregorian",
		"target": "timeFormat"
	},
	"months-standAlone-abbr@localeAlias912": {
		"bundle": "indian",
		"target": "months-format-wide"
	},
	"field-weekOfMonth-narrow": "Week Of Month",
	"field-zone-short@localeAlias1007": {
		"bundle": "",
		"target": "field-zone"
	},
	"days-standAlone-wide@localeAlias924": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"dateFormatItem-yyyyQQQ": "G y QQQ",
	"field-second-short@localeAlias1004": {
		"bundle": "",
		"target": "field-second"
	},
	"dateFormatItem-yyyyMMMM": "G y MMMM",
	"dateFormatItem-y": "G y",
	"quarters-standAlone-wide@localeAlias930": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-minute-relative+0": "this minute",
	"field-year-short-relative+0": "this year",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-year-short-relative+1": "next year",
	"field-weekday": "Day of the Week",
	"dayPeriods-format-narrow-pm": "PM",
	"dateTimeFormats-appendItem-Quarter": "{0} ({2}: {1})",
	"field-tue-narrow-relative+-1": "last Tuesday",
	"dateTime@localeAlias943": {
		"bundle": "generic",
		"target": "dateTime"
	},
	"field-minute-narrow@localeAlias1002": {
		"bundle": "",
		"target": "field-minute-short"
	},
	"field-minute-narrow@localeAlias1003": {
		"bundle": "",
		"target": "field-minute"
	},
	"field-tue-narrow@localeAlias981": {
		"bundle": "",
		"target": "field-tue-short"
	},
	"field-year-narrow-relative+-1": "last year",
	"dateFormatItem-yyyyMMMd": "G y MMM d",
	"field-tue-narrow@localeAlias982": {
		"bundle": "",
		"target": "field-tue"
	},
	"field-sat-relative+-1": "last Saturday",
	"field-wed-short@localeAlias983": {
		"bundle": "",
		"target": "field-wed"
	},
	"dayPeriods-standAlone-narrow-pm": "PM",
	"field-mon-narrow-relative+0": "this Monday",
	"field-mon-narrow-relative+1": "next Monday",
	"field-second": "Second",
	"field-year-relative+-1": "last year",
	"field-weekdayOfMonth-short": "Weekday Of Month",
	"dateFormat-short": "GGGGG y-MM-dd",
	"eraNames": [
		"Saka"
	],
	"field-second-short": "Second",
	"quarters-format-narrow@localeAlias927": {
		"bundle": "gregorian",
		"target": "quarters-standAlone-narrow"
	},
	"field-thu-short-relative+-1": "last Thursday",
	"field-zone": "Zone",
	"field-dayperiod-narrow": "Dayperiod",
	"field-sun-short-relative+-1": "last Sunday",
	"field-year-narrow@localeAlias948": {
		"bundle": "",
		"target": "field-year-short"
	},
	"eraAbbr": [
		"Saka"
	],
	"field-week-short": "Week",
	"dayPeriods-standAlone-abbr-am": "AM",
	"field-year-narrow@localeAlias949": {
		"bundle": "",
		"target": "field-year"
	},
	"dayPeriods-standAlone-wide-pm": "PM",
	"field-hour-short@localeAlias998": {
		"bundle": "",
		"target": "field-hour"
	},
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+0": "today",
	"field-day-relative+1": "tomorrow",
	"days-standAlone-short@localeAlias921": {
		"bundle": "gregorian",
		"target": "days-format-short"
	},
	"days-standAlone-short@localeAlias922": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"field-month-narrow@localeAlias954": {
		"bundle": "",
		"target": "field-month-short"
	},
	"days-standAlone-short@localeAlias923": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-month-narrow@localeAlias955": {
		"bundle": "",
		"target": "field-month"
	},
	"field-day-short-relative+0": "today",
	"field-dayOfYear-short": "Day Of Year",
	"field-day-short-relative+1": "tomorrow",
	"dateFormat-long": "G y MMMM d",
	"field-weekOfMonth-short@localeAlias959": {
		"bundle": "",
		"target": "field-weekOfMonth"
	},
	"field-sun-narrow-relative+-1": "last Sunday",
	"field-second-relative+0": "now",
	"field-quarter-relative+-1": "last quarter",
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-week-relative+-1": "last week",
	"field-sat-short@localeAlias992": {
		"bundle": "",
		"target": "field-sat"
	},
	"days-format-abbr@localeAlias915": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-month-relative+-1": "last month",
	"months-standAlone-wide@localeAlias913": {
		"bundle": "indian",
		"target": "months-format-wide"
	},
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-year": "Year",
	"field-era": "Era",
	"days-standAlone-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-short-relative+-1": "yesterday",
	"months-format-abbr@localeAlias909": {
		"bundle": "indian",
		"target": "months-format-wide"
	},
	"dateFormatItem-GyMMM": "G y MMM",
	"timeFormat-full": "HH:mm:ss zzzz",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-day-short@localeAlias962": {
		"bundle": "",
		"target": "field-day"
	},
	"field-hour": "Hour",
	"field-month-short@localeAlias953": {
		"bundle": "",
		"target": "field-month"
	},
	"days-format-narrow@localeAlias916": {
		"bundle": "gregorian",
		"target": "days-standAlone-narrow"
	},
	"field-dayOfYear-narrow": "Day Of Year",
	"field-second-narrow-relative+0": "now",
	"field-quarter": "Quarter",
	"field-month-narrow-relative+0": "this month",
	"field-month-narrow-relative+1": "next month",
	"field-dayOfYear-narrow@localeAlias966": {
		"bundle": "",
		"target": "field-dayOfYear-short"
	},
	"field-weekday-short@localeAlias968": {
		"bundle": "",
		"target": "field-weekday"
	},
	"field-dayOfYear-narrow@localeAlias967": {
		"bundle": "",
		"target": "field-dayOfYear"
	},
	"field-mon-narrow@localeAlias978": {
		"bundle": "",
		"target": "field-mon-short"
	},
	"field-mon-narrow@localeAlias979": {
		"bundle": "",
		"target": "field-mon"
	},
	"dateFormatItem-yyyy": "G y",
	"dateTimeFormats-appendItem-Minute": "{0} ({2}: {1})",
	"field-day": "Day",
	"field-mon-relative+-1": "last Monday",
	"field-sun-narrow@localeAlias975": {
		"bundle": "",
		"target": "field-sun-short"
	},
	"field-sun-narrow@localeAlias976": {
		"bundle": "",
		"target": "field-sun"
	},
	"field-dayOfYear": "Day Of Year",
	"dateFormat-medium": "G y MMM d",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-GyMMMd": "G y MMM d",
	"dateFormatItem-MEd": "MM-dd, E",
	"field-tue-short-relative+-1": "last Tuesday",
	"field-year-short": "Year",
	"dayPeriods@localeAlias931": {
		"bundle": "gregorian",
		"target": "dayPeriods"
	},
	"field-month-short": "Month",
	"field-hour-narrow@localeAlias1000": {
		"bundle": "",
		"target": "field-hour"
	},
	"dateFormatItem-MMMEd": "MMM d, E",
	"dateFormatItem-MMMd": "MMM d",
	"dateFormatItem-Bh": "h B",
	"months-format-abbr": [
		"Chaitra",
		"Vaisakha",
		"Jyaistha",
		"Asadha",
		"Sravana",
		"Bhadra",
		"Asvina",
		"Kartika",
		"Agrahayana",
		"Pausa",
		"Magha",
		"Phalguna"
	],
	"dayPeriods-format-abbr-am": "AM",
	"field-sat-relative+0": "this Saturday",
	"dayPeriods-format-wide-pm": "PM",
	"field-sat-relative+1": "next Saturday",
	"days-standAlone-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-weekday-narrow@localeAlias969": {
		"bundle": "",
		"target": "field-weekday-short"
	},
	"field-zone-short": "Zone",
	"field-week-short-relative+0": "this week",
	"field-week-short-relative+1": "next week",
	"dateFormatItem-yyyyMMMEd": "G y MMM d, E",
	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
	"field-fri-short-relative+-1": "last Friday",
	"field-month-narrow": "Month",
	"field-week-narrow@localeAlias957": {
		"bundle": "",
		"target": "field-week-short"
	},
	"dayPeriods-format-narrow-am": "AM",
	"field-week-narrow@localeAlias958": {
		"bundle": "",
		"target": "field-week"
	},
	"field-era-narrow@localeAlias945": {
		"bundle": "",
		"target": "field-era-short"
	},
	"field-month-narrow-relative+-1": "last month",
	"field-era-narrow@localeAlias946": {
		"bundle": "",
		"target": "field-era"
	},
	"days-format-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-weekday-short": "Day of the Week",
	"field-weekday-narrow@localeAlias970": {
		"bundle": "",
		"target": "field-weekday"
	},
	"field-zone-narrow@localeAlias1008": {
		"bundle": "",
		"target": "field-zone-short"
	},
	"field-day-narrow-relative+-1": "yesterday",
	"field-zone-narrow@localeAlias1009": {
		"bundle": "",
		"target": "field-zone"
	},
	"field-quarter-short": "Quarter",
	"days-format-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"dateFormatItem-EHm": "E HH:mm",
	"field-quarter-narrow": "Quarter",
	"field-fri-short@localeAlias989": {
		"bundle": "",
		"target": "field-fri"
	},
	"field-mon-short-relative+0": "this Monday",
	"field-mon-short-relative+1": "next Monday",
	"months-format-narrow@localeAlias910": {
		"bundle": "indian",
		"target": "months-standAlone-narrow"
	},
	"field-dayperiod-short": "Dayperiod",
	"dayPeriods-standAlone-narrow-am": "AM",
	"field-week-narrow-relative+-1": "last week",
	"field-hour-narrow@localeAlias999": {
		"bundle": "",
		"target": "field-hour-short"
	},
	"field-thu-relative+-1": "last Thursday",
	"field-mon-short-relative+-1": "last Monday",
	"field-fri-narrow-relative+-1": "last Friday",
	"timeFormat-medium": "HH:mm:ss",
	"quarters-standAlone-abbr@localeAlias928": {
		"bundle": "gregorian",
		"target": "quarters-format-abbr"
	},
	"quarters-standAlone-abbr@localeAlias929": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-quarter-short-relative+0": "this quarter",
	"field-quarter-short-relative+1": "next quarter",
	"field-thu-narrow@localeAlias987": {
		"bundle": "",
		"target": "field-thu-short"
	},
	"dateFormatItem-Ed": "d, E",
	"field-thu-narrow@localeAlias988": {
		"bundle": "",
		"target": "field-thu"
	},
	"field-wed-relative+-1": "last Wednesday",
	"field-weekOfMonth": "Week Of Month",
	"eraNarrow@localeAlias940": {
		"bundle": "indian",
		"target": "eraAbbr"
	},
	"field-weekdayOfMonth-narrow": "Weekday Of Month",
	"dayPeriods-standAlone-wide-am": "AM",
	"field-dayperiod-narrow@localeAlias996": {
		"bundle": "",
		"target": "field-dayperiod-short"
	},
	"field-dayperiod-narrow@localeAlias997": {
		"bundle": "",
		"target": "field-dayperiod"
	},
	"dayPeriods-standAlone-wide@localeAlias937": {
		"bundle": "gregorian",
		"target": "dayPeriods-standAlone-abbr"
	},
	"dayPeriods-standAlone-wide@localeAlias938": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-fri-relative+-1": "last Friday",
	"field-weekOfMonth-narrow@localeAlias960": {
		"bundle": "",
		"target": "field-weekOfMonth-short"
	},
	"field-weekOfMonth-narrow@localeAlias961": {
		"bundle": "",
		"target": "field-weekOfMonth"
	},
	"field-minute": "Minute",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"days@localeAlias914": {
		"bundle": "gregorian",
		"target": "days"
	},
	"field-second-short-relative+0": "now",
	"quarters-format-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-day-short": "Day",
	"field-dayperiod": "Dayperiod",
	"field-hour-short": "Hour",
	"months-standAlone-abbr": [
		"Chaitra",
		"Vaisakha",
		"Jyaistha",
		"Asadha",
		"Sravana",
		"Bhadra",
		"Asvina",
		"Kartika",
		"Agrahayana",
		"Pausa",
		"Magha",
		"Phalguna"
	],
	"field-dayperiod-short@localeAlias995": {
		"bundle": "",
		"target": "field-dayperiod"
	},
	"field-month-relative+0": "this month",
	"field-second-narrow": "Second",
	"field-month-relative+1": "next month",
	"dateFormat-full": "G y MMMM d, EEEE",
	"dateFormatItem-yyyyMEd": "GGGGG y-MM-dd, E",
	"field-era-narrow": "Era",
	"field-sat-short-relative+-1": "last Saturday",
	"field-week-short@localeAlias956": {
		"bundle": "",
		"target": "field-week"
	},
	"field-week-short-relative+-1": "last week",
	"dateTimeFormat-long": "{1} {0}",
	"field-sun-relative+-1": "last Sunday",
	"field-wed-short-relative+-1": "last Wednesday",
	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
	"field-weekdayOfMonth": "Weekday Of Month",
	"dateFormatItem-yyyyMd": "GGGGG y-MM-dd",
	"quarters-format-abbr@localeAlias926": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-quarter-narrow-relative+0": "this quarter",
	"dateFormatItem-GyMMMEd": "G y MMM d, E",
	"field-quarter-narrow-relative+1": "next quarter",
	"field-sat-short-relative+0": "this Saturday",
	"field-sat-short-relative+1": "next Saturday",
	"field-hour-narrow": "Hour",
	"field-year-narrow-relative+0": "this year",
	"field-year-narrow-relative+1": "next year",
	"dateFormatItem-Gy": "G y",
	"field-fri-narrow@localeAlias990": {
		"bundle": "",
		"target": "field-fri-short"
	},
	"field-zone-narrow": "Zone",
	"field-fri-narrow@localeAlias991": {
		"bundle": "",
		"target": "field-fri"
	},
	"dateFormatItem-yyyyM": "GGGGG y-MM",
	"field-tue-relative+-1": "last Tuesday",
	"field-minute-short": "Minute",
	"dateFormatItem-Hm": "HH:mm",
	"field-week-relative+0": "this week",
	"field-week-relative+1": "next week",
	"dateFormatItem-MMM": "LLL",
	"field-sun-relative+0": "this Sunday",
	"field-sun-relative+1": "next Sunday",
	"dateFormat@localeAlias941": {
		"bundle": "generic",
		"target": "dateFormat"
	},
	"field-sat-narrow-relative+-1": "last Saturday",
	"dateTimeFormats-appendItem-Month": "{0} ({2}: {1})",
	"quarters-standAlone-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-sun-short@localeAlias974": {
		"bundle": "",
		"target": "field-sun"
	},
	"field-quarter-short@localeAlias950": {
		"bundle": "",
		"target": "field-quarter"
	},
	"field-month-short-relative+-1": "last month",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-MMMMd": "MMMM d",
	"field-week": "Week",
	"field-day-narrow": "Day",
	"field-hour-narrow-relative+0": "this hour"
}
//end v1.x content
,
	"cs": true,
	"da": true,
	"de": true,
	"el": true,
	"en-au": true,
	"es": true,
	"fi": true,
	"fr": true,
	"he": true,
	"hr": true,
	"hu": true,
	"id": true,
	"ja": true,
	"mk": true,
	"nb": true,
	"nl": true,
	"pl": true,
	"ro": true,
	"ru": true,
	"sk": true,
	"sr": true,
	"sv": true,
	"th": true,
	"tr": true,
	"zh": true,
	"zh-hant": true
});